package com.umfintech.umfpaysdk;

import android.app.Application;

import com.umfintech.umfpaysdk.callback.BankCardPayCallBack;
import com.umfintech.umfpaysdk.callback.BankRefundCallback;
import com.umfintech.umfpaysdk.callback.CancelCardCallback;
import com.umfintech.umfpaysdk.callback.CardPayQueryCallBack;
import com.umfintech.umfpaysdk.callback.DeviceBindCallBack;
import com.umfintech.umfpaysdk.callback.PrintCallback;
import com.umfintech.umfpaysdk.callback.QueryListCallBack;
import com.umfintech.umfpaysdk.callback.RefundStateQueryCallback;
import com.umfintech.umfpaysdk.callback.ScanPayCallBack;
import com.umfintech.umfpaysdk.callback.ScanQueryCallBack;
import com.umfintech.umfpaysdk.callback.ScanRefundCallback;
import com.umpay.payplugin.UMPay;
import com.umpay.payplugin.bean.BankCardPayRequest;
import com.umpay.payplugin.bean.CardPayQueryRequest;
import com.umpay.payplugin.bean.OrderListRequest;
import com.umpay.payplugin.bean.PrintInfo;
import com.umpay.payplugin.bean.RefundQueryRequest;
import com.umpay.payplugin.bean.RefundRequest;
import com.umpay.payplugin.bean.ScanPayRequest;
import com.umpay.payplugin.util.UMPayLog;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;

/**
 * dec:
 *
 * @author hanpeidong on 2019/8/1.
 */
public class SdkManager {

    static PluginRegistry.Registrar registrarHolder;

    /// 初始化
    static void init(MethodChannel.Result result) {
        UMPay.getInstance().init((Application) registrarHolder.context());
        UMPay.getInstance().bind(registrarHolder.context(), new DeviceBindCallBack(registrarHolder.context(), result));
    }

    /// 初始化
    static void dispose() {
        UMPay.getInstance().unBind();
    }

    /// 扫码付
    static void scanPay(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("doScanPay", call.arguments.toString());
        ScanPayRequest request = new ScanPayRequest();
        try {
            request.amount = call.argument("amount");
            request.mediaNo = call.argument("mediaNo");
            request.goodsDescribe = call.argument("goodsDescribe");
            request.goodsInfo = call.argument("goodsInfo");
            request.orderId = call.argument("orderId");
            UMPay.getInstance().scanPay(request, new ScanPayCallBack(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("scanPay", "onException: " + e.toString());
            result.error("scanPay", "onException", e.getMessage());
        }
    }
    /// 扫码付查询
    static void scanQuery(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("scanQuery", call.arguments.toString());
        ScanPayRequest request = new ScanPayRequest();
        try {
            request.orderId = call.argument("orderId");
            request.payType = call.argument("payType");
            //订单时间 格式yyyyMMdd （由于数据库做的分表，所以需要传这个字段，如果不传就差当月数据）
            request.orderDate = call.argument("orderDate");
            UMPay.getInstance().scanQuery(request, new ScanQueryCallBack(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("scanQuery", "onException: " + e.toString());
            result.error("scanQuery", "onException", e.getMessage());
        }
    }
    /// 扫码付撤销
    static void scanRevoke(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("scanRevoke", call.arguments.toString());
        RefundRequest request = new RefundRequest();
        try {
            request.amount = call.argument("amount");
            request.orderId = call.argument("orderId");
            request.orderDate = call.argument("orderDate");
            request.payType = call.argument("payType");
            UMPay.getInstance().scanRevoke(request, new ScanRefundCallback(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("scanRevoke", "onException: " + e.toString());
            result.error("scanRevoke", "onException", e.getMessage());
        }
    }
    /// 扫码付退款
    static void scanRefund(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("scanRefund", call.arguments.toString());
        RefundRequest request = new RefundRequest();
        try {
            request.amount = call.argument("amount");
            request.orderId = call.argument("orderId");
            request.orderDate = call.argument("orderDate");
            request.payType = call.argument("payType");
            request.refundPartnerOrderId = call.argument("refundPartnerOrderId");
            UMPay.getInstance().scanRefund(request, new ScanRefundCallback(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("scanRefund", "onException: " + e.toString());
            result.error("scanRefund", "onException", e.getMessage());
        }
    }

    /// 刷卡付
    static void cardPay(EventCall call, EventChannel.EventSink eventSink) {
        UMPayLog.i("cardPay", call.arguments.toString());
        BankCardPayRequest request = new BankCardPayRequest();
        try {
            request.amount = (int) call.argument("amount");
            request.orderId = (String) call.argument("orderId");
            UMPay.getInstance().cardPay(request, new BankCardPayCallBack(registrarHolder.context(), eventSink));
        } catch (Exception e) {
            UMPayLog.i("cardPay", "onException: " + e.toString());
            eventSink.error("cardPay", "onException", e.getMessage());
        }
    }
    /// 刷卡付查询
    static void cardQuery(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("cardQuery", call.arguments.toString());
        CardPayQueryRequest request = new CardPayQueryRequest();
        try {
            request.orderId = call.argument("orderId");
            //订单时间 格式yyyyMMdd （由于数据库做的分表，所以需要传这个字段，如果不传就差当月数据）
            request.orderDate = call.argument("orderDate");
            UMPay.getInstance().cardQuery(request, new CardPayQueryCallBack(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("cardQuery", "onException: " + e.toString());
            result.error("cardQuery", "onException", e.getMessage());
        }
    }
    /// 银行卡撤销
    static void bankRevoke(EventCall call, EventChannel.EventSink eventSink) {
        UMPayLog.i("bankRevoke", call.arguments.toString());
        RefundRequest request = new RefundRequest();
        try {
            request.amount = (int) call.argument("amount");
            request.orderId = (String) call.argument("orderId");
            request.orderDate = (String) call.argument("orderDate");
            request.payType = (String) call.argument("payType");
            UMPay.getInstance().bankRevoke(request, new BankRefundCallback(registrarHolder.context(), eventSink));
        } catch (Exception e) {
            UMPayLog.i("bankRevoke", "onException: " + e.toString());
            eventSink.error("bankRevoke", "onException", e.getMessage());
        }
    }
    /// 银行卡退款
    static void bankRefund(EventCall call, EventChannel.EventSink eventSink) {
        UMPayLog.i("cardRefund", call.arguments.toString());
        RefundRequest request = new RefundRequest();
        try {
            request.amount = (int) call.argument("amount");
            request.orderId = (String) call.argument("orderId");
            request.orderDate = (String) call.argument("orderDate");
            request.payType = (String) call.argument("payType");
            request.refundPartnerOrderId = (String) call.argument("refundPartnerOrderId");
            UMPay.getInstance().bankRefund(request, new BankRefundCallback(registrarHolder.context(), eventSink));
        } catch (Exception e) {
            UMPayLog.i("bankRefund", "onException: " + e.toString());
            eventSink.error("bankRefund", "onException", e.getMessage());
        }
    }
    /// 查询退款
    static void refundQuery(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("refundQuery", call.arguments.toString());
        RefundQueryRequest request = new RefundQueryRequest();
        try {
            request.orderId = call.argument("orderId");
            //订单时间 格式yyyyMMdd （由于数据库做的分表，所以需要传这个字段，如果不传就差当月数据）
            request.orderDate = call.argument("orderDate");
            UMPay.getInstance().refundQuery(request, new RefundStateQueryCallback(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("refundQuery", "onException: " + e.toString());
            result.error("refundQuery", "onException", e.getMessage());
        }
    }
    /// 查询订单列表
    static void getOrderList(MethodCall call, MethodChannel.Result result) {
        UMPayLog.i("refundQuery", call.arguments.toString());
        try {
            OrderListRequest listRequest = new OrderListRequest();
            listRequest.payType = call.argument("payType");
            listRequest.pageIndex = call.argument("pageIndex");
            listRequest.pageSize = call.argument("pageSize");
            listRequest.orderDate = call.argument("orderDate");//订单日期
            listRequest.orderId = call.argument("orderId");//订单号
            listRequest.orderState = call.argument("orderState");//订单状态
            UMPay.getInstance().getOrderList(listRequest, new QueryListCallBack(registrarHolder.context(), result));
        } catch (Exception e) {
            UMPayLog.i("refundQuery", "onException: " + e.toString());
            result.error("refundQuery", "onException", e.getMessage());
        }
    }
    /// 取消读卡
    static void stopSearchCard(MethodChannel.Result result) {
        UMPay.getInstance().stopSearchCard(new CancelCardCallback(registrarHolder.context(), result));
    }

    /// 读取设备sn
    static void getDeviceSN(MethodChannel.Result result) {
        result.success(UMPay.getInstance().getPosSn());
    }

    /// 打印
    static void print(EventCall call, EventChannel.EventSink eventSink) {
        UMPayLog.i("print", call.arguments.toString());
        try {
            PrintInfo info = new PrintInfo();
            info.lineSpace = 4;      //行间距
            UMPay.getInstance().print((String) call.argument("content"), info, new PrintCallback(registrarHolder.context(), eventSink));
        } catch (Exception e) {
            UMPayLog.i("print", "onException: " + e.toString());
            eventSink.error("print", "onException", e.getMessage());
        }
    }
}
