package com.umfintech.umfpaysdk;

import android.content.Context;
import android.net.ConnectivityManager;
import android.util.Log;

import com.umpay.payplugin.UMPay;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** UmfpaysdkPlugin */
public class UmfpaysdkPlugin implements MethodCallHandler, EventChannel.StreamHandler {
  /** Plugin registration. */
  private final Registrar registrar;

  public static void registerWith(Registrar registrar) {
    SdkManager.registrarHolder = registrar;
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "plugins.flutter.io/umfpaysdk");
    final EventChannel cardPayEventChannel =
            new EventChannel(registrar.messenger(), "plugins.flutter.io/umfpaysdk_cardPay");
    UmfpaysdkPlugin instance = new UmfpaysdkPlugin(registrar);
    channel.setMethodCallHandler(instance);
    cardPayEventChannel.setStreamHandler(new CardPayStreamHandler());
  }

  private UmfpaysdkPlugin(Registrar registrar) {
    this.registrar = registrar;
  }

  @Override
  public void onMethodCall(MethodCall call, final Result result) {
    Log.i("onMethodCall", call.method + " params: " + call.arguments);
    switch (call.method) {
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "init": // 初始化
        SdkManager.init(result);
        break;
      case "dispose": // 注销
        SdkManager.dispose();
        break;
      case "scanPay": // 扫码付
        SdkManager.scanPay(call, result);
        break;
      case "scanQuery": // 扫码付订单状态查询
        SdkManager.scanQuery(call, result);
        break;
      case "cardPay": // 刷卡付 使用EventChannel
//        SdkManager.cardPay(call, result);
        break;
      case "cardQuery": // 刷卡付订单状态查询
        SdkManager.cardQuery(call, result);
        break;
      case "scanRevoke": // 扫码付撤销
        SdkManager.scanRevoke(call, result);
        break;
      case "bankRevoke": // 银行卡撤销
//        SdkManager.bankRevoke(call, result);
        break;
      case "scanRefund": // 扫码付退款
        SdkManager.scanRefund(call, result);
        break;
      case "bankRefund": // 银行卡退款
//        SdkManager.bankRefund(call, result);
        break;
      case "refundQuery": // 查询退款
        SdkManager.refundQuery(call, result);
        break;
      case "getOrderList": // 查询订单列表
        SdkManager.getOrderList(call, result);
        break;
      case "stopSearchCard": // 取消读卡
        SdkManager.stopSearchCard(result);
        break;
      case "getDeviceSN": // 获取设备sn
        SdkManager.getDeviceSN(result);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onListen(Object o, EventChannel.EventSink eventSink) {
    Log.i("onListen", "发送事件");
    eventSink.success("success");// 发送事件
  }

  @Override
  public void onCancel(Object o) {

  }
}
