import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:umfpaysdk/pay_sdk_request.dart';
import 'package:umfpaysdk/umfpaysdk.dart';

import 'util.dart';

/// desc:
/// author: hanpeidong
/// time: 2019/8/2
class CardPayCard extends StatefulWidget {
  @override
  _CardPayCardState createState() => _CardPayCardState();
}

class _CardPayCardState extends State<CardPayCard> {
  TextEditingController qrController = TextEditingController();
  TextEditingController orderIdController =
      TextEditingController(text: "cardpay${getOrderId()}");
  static const EventChannel eventChannel =
      const EventChannel('plugins.flutter.io/umfpaysdk_event');

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Card(
      color: Colors.blue,
      elevation: 5,
      shape: new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(4)),
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: <Widget>[
            TextField(
              controller: orderIdController,
              decoration: InputDecoration(
                prefixText: "订单号：",
              ),
            ),
            FlatButton(
              color: Colors.deepOrange,
              onPressed: () {
                PaySdkRequest request =
                    PaySdkRequest(amount: 1, orderId: orderIdController.text);
                Umfpaysdk.cardPay(request,
                    onEvent: _onEvent, onError: _onError);
              },
              child: Text(
                "刷卡付",
                style: TextStyle(color: Colors.white),
              ),
            ),
            FlatButton(
              color: Colors.deepOrange,
              onPressed: () {
                PaySdkRequest request = PaySdkRequest(
                    orderDate: "", orderId: orderIdController.text);
                Umfpaysdk.cardQuery(request).then((result) {
                  print("cardQuery result: $result");
                  showAlertDialog(context, result.toString());
                });
              },
              child: Text(
                "刷卡付订单状态查询",
                style: TextStyle(color: Colors.white),
              ),
            ),
            FlatButton(
              color: Colors.deepOrange,
              onPressed: () {
                PaySdkRequest request = PaySdkRequest(
                    amount: 1,
                    orderDate: "20190802",
                    orderId: orderIdController.text,
                    payType: "YS",
                );
                Umfpaysdk.bankRevoke(request,
                    onEvent: _onEvent, onError: _onError);
              },
              child: Text(
                "刷卡付撤销",
                style: TextStyle(color: Colors.white),
              ),
            ),
            FlatButton(
              color: Colors.deepOrange,
              onPressed: () {
                PaySdkRequest request = PaySdkRequest(
                    amount: 1,
                    orderDate: "20190802",
                    orderId: orderIdController.text,
                    payType: "YS",
                    refundPartnerOrderId:
                        "refundPartner${orderIdController.text}");
                Umfpaysdk.bankRefund(request,
                    onEvent: _onEvent, onError: _onError);
              },
              child: Text(
                "刷卡付退款",
                style: TextStyle(color: Colors.white),
              ),
            ),
          ],
        ),
      ),
    );
  }

  // 回调事件
  void _onEvent(Object event) {
    print("刷卡付 result: " + event);
    showAlertDialog(context, event);
  }

  // 错误返回
  void _onError(Object error) {
    print("刷卡付 result: Error");
    showAlertDialog(context, "Error");
  }
}
