/// desc: 打印信息
/// author: hanpeidong
/// time: 2019/8/26
class PrintInfo {
  final List<String> positions = ["left", "center", "right"];

  // ignore: non_constant_identifier_names
  String content_type;
  String content;
  String size;
  String position;
  String offset;
  String bold;
  String italic;
  String height;

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['content-type'] = this.content_type;
    data['content'] = this.content;
    data['size'] = this.size;
    data['position'] = this.position;
    data['offset'] = this.offset;
    data['bold'] = this.bold;
    data['italic'] = this.italic;
    data['height'] = this.height;
    return data;
  }

  /// 打印文字
  PrintInfo.fromContent(String content, int position, int size) {
    this.content_type = "txt";
    this.content = content;
    this.size = size.toString();
    this.position = position > positions.length? positions[0]: positions[position - 1];
    this.offset = "0";
    this.bold = "0";
    this.italic = "0";
    this.height = "-1";
  }

  /// 打印空行 其中使用参数1 ：打印就空行个数 例如传入“3”则打印3个空行
  PrintInfo.fromFreeLine(String num) {
    this.content_type = "feed-line";
    this.content = num;
  }

  /// 二维码
  PrintInfo.fromQRCode(String content, int position, int size) {
    this.content_type = "two-dimension";
    this.content = content;
    this.size = size.toString();
    this.position = position > positions.length? positions[0]: positions[position - 1];
  }

  /// 一维码
  PrintInfo.fromOneCode(String content, int position, int size, int height) {
    this.content_type = "two-dimension";
    this.content = content;
    this.size = size.toString();
    this.position = position > positions.length? positions[0]: positions[position - 1];
    this.offset = "0";
    this.bold = "0";
    this.italic = "0";
    this.height = height.toString();
  }

  /// 分割线
  PrintInfo.fromLine() {
    this.content_type = "line";
  }

  /// 打印图片
  PrintInfo.fromBitmap(int position) {
    this.content_type = "jpg";
    this.position = position > positions.length? positions[0]: positions[position - 1];
  }


}