import 'dart:async';
import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:umfpaysdk/pay_sdk_request.dart';
import 'package:umfpaysdk/print_info.dart';
import 'package:umfpaysdk/sdk_result.dart';

class Umfpaysdk {
  static const MethodChannel _channel = const MethodChannel('plugins.flutter.io/umfpaysdk');
  static const EventChannel cardPayEventChannel = EventChannel('plugins.flutter.io/umfpaysdk_cardPay');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<dynamic> init() async {
    var result = await _channel.invokeMethod('init');
    return result;
  }

  static Future<dynamic> dispose() async {
    var result = await _channel.invokeMethod('dispose');
    return result;
  }

  static Future<SdkResult> scanPay(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'scanPay',
        {
          'amount': paySdkRequest.amount,
          'mediaNo': paySdkRequest.mediaNo,
          "goodsDescribe": paySdkRequest.goodsDescribe,
          "goodsInfo": paySdkRequest.goodsInfo,
          "orderId": paySdkRequest.orderId
        }
    );
    print("scanPay return result: $result");
    return SdkResult.fromJson(json.decode(result));
  }

  static Future<SdkResult> scanQuery(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'scanQuery',
        {
          'orderId': paySdkRequest.orderId,
          'payType': paySdkRequest.payType,
          "orderDate": paySdkRequest.orderDate,
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future<SdkResult> scanRevoke(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'scanRevoke',
        {
          'amount': paySdkRequest.amount,
          "orderId": paySdkRequest.orderId,
          "orderDate": paySdkRequest.orderDate,
          "payType": paySdkRequest.payType
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future<SdkResult> scanRefund(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'scanRefund',
        {
          'amount': paySdkRequest.amount,
          "orderId": paySdkRequest.orderId,
          "orderDate": paySdkRequest.orderDate,
          "payType": paySdkRequest.payType,
          "refundPartnerOrderId": paySdkRequest.refundPartnerOrderId,
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future cardPay(PaySdkRequest paySdkRequest, {onEvent, onError}) async {
    cardPayEventChannel.receiveBroadcastStream({
      'eventType': "cardPay",
      'amount': paySdkRequest.amount,
      "orderId": paySdkRequest.orderId
    }).listen(onEvent, onError: onError);
  }

  static Future<SdkResult> cardQuery(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'cardQuery',
        {
          'orderId': paySdkRequest.orderId,
          "orderDate": paySdkRequest.orderDate
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future bankRevoke(PaySdkRequest paySdkRequest, {onEvent, onError}) async {
    cardPayEventChannel.receiveBroadcastStream({
      'eventType': "bankRevoke",
      'amount': paySdkRequest.amount,
      "orderId": paySdkRequest.orderId,
      "orderDate": paySdkRequest.orderDate,
      "payType": paySdkRequest.payType,
    }).listen(onEvent, onError: onError);
  }

  static Future bankRefund(PaySdkRequest paySdkRequest, {onEvent, onError}) async {
    cardPayEventChannel.receiveBroadcastStream({
      'eventType': "bankRefund",
      'amount': paySdkRequest.amount,
      "orderId": paySdkRequest.orderId,
      "orderDate": paySdkRequest.orderDate,
      "payType": paySdkRequest.payType,
      "refundPartnerOrderId": paySdkRequest.refundPartnerOrderId,
    }).listen(onEvent, onError: onError);
  }

  static Future<SdkResult> refundQuery(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'refundQuery',
        {
          "orderId": paySdkRequest.orderId,
          "orderDate": paySdkRequest.orderDate,
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future<SdkResult> getOrderList(PaySdkRequest paySdkRequest) async {
    var result = await _channel.invokeMethod(
        'getOrderList',
        {
          "payType": paySdkRequest.payType,
          "orderDate": paySdkRequest.orderDate,
          "pageIndex": paySdkRequest.pageIndex,
          "pageSize": paySdkRequest.pageSize,
          "orderId": paySdkRequest.orderId,
          "orderState": paySdkRequest.orderState,
        }
    );
    return SdkResult.fromJson(json.decode(result));
  }

  static Future<SdkResult> stopSearchCard() async {
    var result = await _channel.invokeMethod(
        'stopSearchCard',
        {}
    );
    return SdkResult.fromJson(json.decode(result));
  }



  static Future<String> getDeviceSN() async {
    var result = await _channel.invokeMethod(
        'getDeviceSN',
        {}
    );
    return result;
  }

  static Future printer(List<PrintInfo> prints , {onEvent, onError}) async {
    String content = json.encode({"spos": prints});
    cardPayEventChannel.receiveBroadcastStream({
      'eventType': "print",
      'content': content,
    }).listen(onEvent, onError: onError);
  }
}
